ExternalDependentVariable — csdmpy 0.1.1 documentation

# ExternalDependentVariable

## Generalized Class

DependentVariable

### Description

An ExternalDependentVariable is where the components of the dependent variable are defined in an external file whose location is defined as the value of the `components_url` key.

### Attributes

Name | Type | Description
--- | --- | ---
components_url | String | The location where the components of the dependent variable are stored as a binary data.